ProtocolInterface class abstract
- Implementers
Constructors
- ProtocolInterface()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
crc16(
List< int> payload) → List<int> -
generate(
int command, List< int> ? data) → Uint8List -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parse(
List< int> packet) → PacketStructure? -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited